@@ -1637,10 +1637,10 @@ int32_t SPVM__Math__nan(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   void* string = stack[0].oval;
   if (string == NULL) {
-    return env->die(env, "String must be defined", MFILE, __LINE__);
+    return env->die(env, stack, "String must be defined", MFILE, __LINE__);
   }
 
-  const char* tagp = env->get_chars(env, string);
+  const char* tagp = env->get_chars(env, stack, string);
   double value = nan(tagp);
 
   stack[0].dval = value;
@@ -1662,10 +1662,10 @@ int32_t SPVM__Math__nanf(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   void* string = stack[0].oval;
   if (string == NULL) {
-    return env->die(env, "String must be defined", MFILE, __LINE__);
+    return env->die(env, stack, "String must be defined", MFILE, __LINE__);
   }
 
-  const char* tagp = env->get_chars(env, string);
+  const char* tagp = env->get_chars(env, stack, string);
   float value = nanf(tagp);
 
   stack[0].fval = value;
